@@ -1,6 +1,7 @@
 #! /usr/bin/env python
+# -*- coding: iso-8859-1 -*-
 # vi:ts=4:et
-# $Id: test_stringio.py,v 1.4 2002/08/29 14:39:21 mfx Exp $
+# $Id$
 
 import sys
 try:
@@ -9,9 +10,9 @@ except ImportError:
     from StringIO import StringIO
 import pycurl
 
-url = 'http://curl.haxx.se/dev/'
+url = "http://curl.haxx.se/dev/"
 
-print 'Testing', pycurl.version
+print "Testing", pycurl.version
 
 body = StringIO()
 c = pycurl.Curl()
